<?php

namespace App\Http\Controllers\Admin\Exam;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\ResponseCodeEnum;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Contracts\Repositories\Exam\PaperResultRepository;
use App\Repositories\Validators\Exam\PaperResultValidator;

/**
 * Class PaperResultsController.
 *
 * @package namespace App\Http\Controllers\Exam;
 */
class PaperResultsController extends Controller
{
    /**
     * @var PaperResultRepository
     */
    protected $repository;

    /**
     * @var PaperResultValidator
     */
    protected $validator;

    /**
     * PaperResultsController constructor.
     *
     * @param PaperResultRepository $repository
     * @param PaperResultValidator $validator
     */
    public function __construct(PaperResultRepository $repository, PaperResultValidator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
    }

    /**
     * 考试记录
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function index(Request $request)
    {
        $lists = $this->repository->paginate($request->get('per_page', self::PAGE_NUM));
        return Response::success($lists);
    }

    /**
     * 删除
     * @param $id
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function destroy($id)
    {
        try {
            $this->repository->delete($id);
            return Response::success(null, T('successfully delete.'));
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }

    /**
     * 详情
     * @param $slug
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function show($id)
    {
        $model = $this->repository->where('id', $id)->first();
        if (!$model) {
            return $this->error('找不到资源');
        }
        $model = $this->repository->parserResult($model);
        return Response::success($model);
    }
}
