<?php

namespace App\Http\Controllers\Api\Course;

use App\Http\Controllers\Controller;
use App\Repositories\Criteria\Course\ChapterCriteria;
use App\Repositories\Enums\ResponseCodeEnum;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Prettus\Validator\Contracts\ValidatorInterface;
use App\Contracts\Repositories\Course\ChapterRepository;
use App\Repositories\Validators\Course\ChapterValidator;

/**
 * 章节管理
 * Class CourseChaptersController.
 *
 * @package namespace App\Http\Controllers;
 */
class ChapterController extends Controller
{
    /**
     * @var ChapterRepository
     */
    protected $repository;

    /**
     * @var ChapterValidator
     */
    protected $validator;

    /**
     * CourseChaptersController constructor.
     *
     * @param ChapterRepository $repository
     * @param ChapterValidator $validatorE
     */
    public function __construct(ChapterRepository $repository, ChapterValidator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
    }

    /**
     * 列表
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function index()
    {
        $this->repository->pushCriteria(ChapterCriteria::class);
        $courseChapters = $this->repository->all();
        return Response::success($courseChapters);
    }

    /**
     * 创建
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource|void
     * @throws \Illuminate\Validation\ValidationException
     * Author: Mead
     */
    public function store(Request $request)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_CREATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE)));
            $courseChapter = $this->repository->create($data);
            return Response::success($courseChapter);
        } catch (\Exception $e) {
            return $this->errorStore($e);
        }
    }

    /**
     * 更新
     * @param Request $request
     * @param $id
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * Author: Mead
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_UPDATE));
        try {
            $courseChapter = $this->repository->update($request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_UPDATE))), $id);
            return Response::success($courseChapter);
        } catch (\Exception $e) {
            $this->errorStore($e);
        }
    }

    /**
     * 删除
     * @param $id
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function destroy($id)
    {
        try {
            $this->repository->delete($id);
            return Response::success(null, T('successfully delete.'));
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }
}
