<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Providers;

use Carbon\Carbon;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\ServiceProvider;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     */
    public function register()
    {
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        if (App::getLocale() == 'zh_CN') {

            Carbon::setLocale('zh');
        }

        $this->registerObservers(); // 注册观察者


        Validator::extend('mobile', function ($attribute, $value, $parameters) {
            return preg_match('/^1[3456789][0-9]{9}$/', $value);
        }, T('mobile'));

        //记录执行效率
        DB::listen(function ($query) {
            $location = collect(debug_backtrace())->filter(function ($trace) {
                if (!isset($trace['file'])) {
                    return [
                        'file' => '',
                        'line' => 0,
                    ];
                }
                return !str_contains($trace['file'], 'vendor/');
            })->first(); // grab the first element of non vendor/ calls

            if (!isset($location['file'])) {
                $location = [
                    'file' => '',
                    'line' => 0,
                ];
            }
            $bindings = implode(", ", $query->bindings); // format the bindings as string

            Log::info("
            ------------
            Sql: $query->sql
            Bindings: $bindings
            Time: $query->time
            File: ${location['file']}
            Line: ${location['line']}
            ------------
        ");
        });
    }

    protected function registerObservers(): void
    {
    }
}
