<?php

namespace App\Repositories\Criteria\Area;

use App\Repositories\Enums\Base\RoleEnum;
use App\Repositories\Enums\ModelStatusEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class ProjectsCriteria.
 *
 * @package namespace App\Repositories\Criteria\Area;
 */
class ProjectsCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('shop_id')) {
            $shop_id = $this->request->get('shop_id');
            $model = $model->where('shop_id', '=', $shop_id);
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        } else {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }

        if (is_admin_login()) {
            $admin = login_admin();
            if ($admin->role_id > RoleEnum::ADMIN) {
                $model = $model->where('shop_id', $admin->shop_id);

                if ($admin->role_id == RoleEnum::PROJECT) {
                    $model = $model->whereIn('id', $admin->project_ids);
                }
            }
        }

        $model = $model->orderByDesc('id');
        return $model;
    }
}
