<?php

namespace App\Repositories\Criteria\Base;

use App\Repositories\Enums\ModelStatusEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class ShopCriteria.
 *
 * @package namespace App\Repositories\Criteria\Base;
 */
class ShopCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        } else {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }

        $model = $model->orderByDesc('id');
        return $model;
    }
}
