<?php

namespace App\Repositories\Criteria\Course;

use App\Repositories\Enums\ModelStatusEnum;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class CourseCriteria.
 *
 * @package namespace App\Repositories\Criteria;
 */
class CourseCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('title')) {
            $title = $this->request->get('title');
            $model = $model->where('title', 'like', "%{$title}%");
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        } else {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }

        if ($this->request->filled('is_published')) {
            $is_published = $this->request->get('is_published', false);
            if ($is_published) {
                $model = $model->where('published_at', '<', Carbon::now());
            }
        }

        if ($this->request->filled('is_release')) {
            $is_release = $this->request->get('is_release', false);
            if ($is_release) {
                $model = $model->where('published_at', '<', Carbon::now());
            }
        }


        if ($this->request->filled('category_id')) {
            $category_id = $this->request->get('category_id', false);
            if ($category_id) {
                $model = $model->where('category_id', '=', $category_id);
            }
        }

        if ($this->request->filled('is_teacher_me') && $this->request->get('is_teacher_me')) {
            $model = $model->where('user_id', '=', login_user_id());
        }

        if ($this->request->filled('organization_id')) {
            $organization_id = $this->request->get('organization_id');
            $model = $model->whereHas('organizations', function ($query) use ($organization_id) {
                return $query->where('organization_id', $organization_id);
            });
        }

        if ($this->request->filled('collection') && $this->request->get('collection')) {
            $model = $model->whereHas('collections', function ($query) {
                return $query->where('user_id', login_user_id());
            });
        }

        if ($this->request->filled('tag')) {
            $tag = $this->request->get('tag');
            switch ($tag) {
                case 'new':
                    $model = $model->orderByDesc('id');
                    break;
                case 'hot':
                    $model = $model->orderByDesc('user_count')->orderByDesc('id');
                    break;
                case 'rec':
                    $model = $model->orderByDesc('is_rec')->orderByDesc('id');
                    break;
            }
        } else {
            $model = $model->orderByDesc('sort')->orderByDesc('id');
        }

        return $model;
    }
}
