<?php

namespace App\Repositories\Criteria\Course;

use App\Repositories\Enums\ModelStatusEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class OrganizationCriteria.
 *
 * @package namespace App\Repositories\Criteria\Course;
 */
class OrganizationCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        } else {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }

        if ($this->request->filled('is_issue')) {
            $is_issue = $this->request->get('is_issue');
            $model = $model->where('is_issue', '=', $is_issue);
        }

        if ($this->request->filled('is_release')) {
            $is_release = $this->request->get('is_release');
            $model = $model->where('is_issue', '=', $is_release);
        }

//        if ($this->request->filled('category_id')) {
//            $category_id = $this->request->get('category_id', false);
//            $model = $model->where('category_id', '=', $category_id);
//        }

        if ($this->request->filled('is_teacher_me') && $this->request->get('is_teacher_me')) {
            $model = $model->where('coordinator_id', '=', login_user_id());
        }

        if ($this->request->filled('is_me') && $this->request->get('is_me')) {
            $model = $model->whereHas('student', function ($query) {
                return $query->where('user_id', login_user_id());
            });
        }
        $model = $model->orderByDesc('id');
        return $model;
    }
}
