<?php

namespace App\Repositories\Criteria\Exam;

use App\Repositories\Enums\ModelStatusEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class PaperResultCriteria.
 *
 * @package namespace App\Repositories\Criteria\Exam;
 */
class PaperResultCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        } else {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }

        if ($this->request->filled('user_id')) {
            $user_id = $this->request->get('user_id', false);
            $model = $model->where('user_id', '=', $user_id);
        }

        if ($this->request->filled('paper_id')) {
            $paper_id = $this->request->get('paper_id', false);
            $model = $model->where('paper_id', '=', $paper_id);
        }

        if ($this->request->filled('is_examines')) {
            $is_examines = $this->request->get('is_examines', false);
            $model = $model->where('is_examines', '=', $is_examines);
        }

        if ($this->request->filled('is_me') && $this->request->get('is_me')) {
            $model = $model->where('user_id', '=', login_user_id());
        }

        if ($this->request->filled('is_teacher_me') && $this->request->get('is_teacher_me')) {
            $model = $model->whereHas('paper', function ($query) {
                return $query->where('user_id', login_user_id());
            });
        }

        if ($this->request->filled('title')) {
            $title = $this->request->get('title');
            $model = $model->whereHas('paper', function ($query) use ($title) {
                return $query->where('title', 'like', "%{$title}%");
            });
        }

        $model = $model->orderByDesc('id');

        return $model;
    }
}
