<?php

namespace App\Repositories\Criteria\Note;

use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Models\Course\OrganizationStudent;
use App\Repositories\Models\Note\Note;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class NoteCriteria.
 *
 * @package namespace App\Repositories\Criteria\Note;
 */
class NoteCriteria implements CriteriaInterface
{
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }

    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('title')) {
            $title = $this->request->get('title');
            $model = $model->where('title', 'like', "%{$title}%");
        }

        if ($this->request->filled('course_id')) {
            $model = $model->where('course_id', '=', $this->request->get('course_id'));
        }

        if ($this->request->filled('course_video_id')) {
            $course_video_id = $this->request->get('course_video_id');
            $model = $model->where('course_video_id', '=', $course_video_id);
        }

        if ($this->request->filled('tags')) {
            $tags = $this->request->get('tags');
            $model = $model->where('tags', 'like', "%-{$tags}-%");
        }

        if ($this->request->filled('status')) {
            $model = $model->where('status', '=', $this->request->get('status'));
        } else {
            $model = $model->where('status', '=', ModelStatusEnum::OK);
        }

        if ($this->request->filled('id')) {
            $model = $model->where('id', '=', $this->request->get('id'));
        }

        if ($this->request->filled('is_release')) {
            $model = $model->where('is_release', '=', $this->request->get('is_release'));
        } else {
            $model = $model->where('is_release', '=', Note::RELEASED_ISSUE);
        }

        if ($this->request->filled('type')) {
            $model = $model->where('type', '=', $this->request->get('type'));
        }

        if ($this->request->filled('me')) {
            $model = $model->where('user_id', login_user_id());
        }
//
        if ($this->request->filled('is_course')) {
            switch ($this->request->get('is_course')) {
                case 0:
                    $model = $model->where('course_id', 0);
                    break;
                case 1:
                    $model = $model->where('course_id', '>', 0);
                    break;
            }
        }

        if ($this->request->filled('organization_id')) {
            $model = $model->where('user_id', 'in', OrganizationStudent::query()->where('organization_id', $this->request->get('organization_id'))->where('status', ModelStatusEnum::OK)->distinct()->pluck('user_id'));
        }
//
        if ($this->request->filled('tag')) {
            $tag = $this->request->get('tag');
            switch ($tag) {
                case 'new':
                    $model = $model->orderByDesc('id');
                    break;
                case 'hot':
                    $model = $model->orderByDesc('good_count')->orderByDesc('id');
                    break;
            }
        } else {
            $model = $model->orderByDesc('id');
        }

        return $model;
    }
}
