<?php

namespace App\Repositories\Models\User;

use App\Repositories\Models\Course\OrganizationStudent;
use App\Repositories\Models\Model;
use Database\Factories\UserFactory;
use Illuminate\Auth\Authenticatable;
use Illuminate\Contracts\Auth\Access\Authorizable as AuthorizableContract;
use Illuminate\Contracts\Auth\Authenticatable as AuthenticatableContract;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Laravel\Lumen\Auth\Authorizable;
use Spatie\Permission\Traits\HasRoles;
use Tymon\JWTAuth\Contracts\JWTSubject;

/**
 * Class Student.
 *
 * @package namespace App\Repositories\Models\User;
 */
class User extends Model implements AuthenticatableContract, AuthorizableContract, JWTSubject
{
    use Authenticatable, Authorizable, HasFactory, HasRoles;

    protected $table = 'base_users';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    protected $hidden = ['password'];

    /**
     * 兼容 Laravel 8 的 Factory.
     *
     * @return UserFactory
     */
    protected static function newFactory()
    {
        return UserFactory::new();
    }

    /**
     * Get the identifier that will be stored in the subject claim of the JWT.
     *
     * @return mixed
     */
    public function getJWTIdentifier()
    {
        return $this->getKey();
    }

    /**
     * Return a key value array, containing any custom claims to be added to the JWT.
     *
     * @return array
     */
    public function getJWTCustomClaims()
    {
        if ($this->attributes['role_id']) {
            //老师
            return ['role' => 'teacher'];
        }
        //学生
        return ['role' => 'user'];
    }

    public function organizations()
    {
        return $this->hasMany(OrganizationStudent::class);
    }

    public function getOrganizationAttribute()
    {
        if ($organization_id = request('organization_id')) {
            return OrganizationStudent::query()->where('user_id', $this->attributes['id'])->where('organization_id', $organization_id)->status()->select(['type'])->first();
        }
        return [];
    }

    public function getHeadimgAttribute($val)
    {
        if (is_null($val)) {
            return path_to_url('default/headImg.jpeg');
        }
        return path_to_url($val);
    }

}
