<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It is a breeze. Simply tell Lumen the URIs it should respond to
| and give it the Closure to call when that URI is requested.
|
*/

/**
 * 基础业务模块
 */
Route::group(['namespace' => 'Base'], function () {
    //登录
    Route::post('/auth/login', 'AuthController@login');

    //上传文件
    Route::post('/common/upload', 'ResourceController@upload');

    //枚举
    Route::get('/common/enums', 'CommonController@enums');

    Route::group([
        'middleware' => 'auth:admins'
    ], function () {
        Route::get('/auth/me', 'AuthController@me');
        Route::put('/auth/me', 'AuthController@update');
        Route::get('/auth/logout', 'AuthController@logout');


        Route::group(['prefix' => 'base'], function () {
            //部门管理
            Route::get('department', 'DepartmentController@index');
            Route::get('department/{id}', 'DepartmentController@show');
            Route::post('department', 'DepartmentController@store');
            Route::post('department/delete', 'DepartmentController@delete');
            Route::put('department/{id}', 'DepartmentController@update');
            Route::delete('department/{id}', 'DepartmentController@destroy');
            Route::get('department-tree', 'DepartmentController@tree');

            //管理员
            Route::get('/admin', 'AdminController@index');
            Route::get('admin/{id}', 'AdminController@show');
            Route::post('admin', 'AdminController@store');
            Route::put('admin/{id}', 'AdminController@update');
            Route::delete('admin/{id}', 'AdminController@destroy');

            //角色
            Route::get('/role', 'RoleController@index');
            Route::get('role/{id}', 'RoleController@show');
            Route::post('role', 'RoleController@store');
            Route::put('role/{id}', 'RoleController@update');
            Route::delete('role/{id}', 'RoleController@destroy');
            Route::get('role-lists', 'RoleController@lists');

            //菜单
            Route::get('/menu', 'MenuController@index');
            Route::get('/menu-icons', 'MenuController@icons');
            Route::get('menu/{id}', 'MenuController@show');
            Route::post('menu', 'MenuController@store');
            Route::put('menu/{id}', 'MenuController@update');
            Route::delete('menu/{id}', 'MenuController@destroy');
            Route::get('menu-tree', 'MenuController@tree');
            Route::get('menu-user', 'MenuController@menus');

            //轮播图管理
            Route::get('banner', 'BannersController@index');
            Route::get('banner/{id}', 'BannersController@show');
            Route::post('banner', 'BannersController@store');
            Route::post('banner/delete', 'BannersController@delete');
            Route::put('banner/{id}', 'BannersController@update');
            Route::delete('banner/{id}', 'BannersController@destroy');

            //商户
            Route::get('/shop', 'ShopsController@index');
            Route::post('/shop', 'ShopsController@store');
            Route::get('/shop/{id}', 'ShopsController@show');
            Route::put('/shop/{id}', 'ShopsController@update');
            Route::delete('/shop/{id}', 'ShopsController@destroy');
            Route::get('/shop-select-options', 'ShopsController@SelectOptions');
        });

    });
});

Route::group([
    'middleware' => 'auth:admins'
], function () {
//    首页
    Route::get('/home', 'HomeController@index');
    //区域
    Route::group(['prefix' => 'area'], function () {
        //项目
//        Route::group(['prefix' => 'project', 'namespace' => 'Area'], function () {
//            Route::get('/', 'ProjectsController@index');
//            Route::post('/', 'ProjectsController@store');
//            Route::get('/info/{id}', 'ProjectsController@show');
//            Route::put('/{id}', 'ProjectsController@update');
//            Route::delete('/{id}', 'ProjectsController@destroy');
//            Route::get('/select-options', 'ProjectsController@SelectOptions');
//        });

        Route::group(['namespace' => 'Area'], function () {
            Route::get('/', 'AreasController@index');
            Route::get('/no-page', 'AreasController@indexNoPage');
            Route::get('/trees', 'AreasController@trees');
            Route::get('/select-options', 'AreasController@selectOptions');
            Route::post('/', 'AreasController@store');
            Route::get('/info/{id}', 'AreasController@show');
            Route::put('/{id}', 'AreasController@update');
            Route::delete('/{id}', 'AreasController@destroy');
            Route::post('/delete', 'AreasController@delete');
            Route::get('/select-options-trees', 'AreasController@selectOptionTrees');


            Route::group(['prefix' => 'project'], function () {
                Route::get('/', 'ProjectsController@index');
                Route::post('/', 'ProjectsController@store');
                Route::get('/info/{id}', 'ProjectsController@show');
                Route::put('/{id}', 'ProjectsController@update');
                Route::delete('/{id}', 'ProjectsController@destroy');
                Route::get('/select-options', 'ProjectsController@SelectOptions');

                Route::get('/areas', 'ProjectsController@project');
                Route::get('/areas-tree', 'ProjectsController@projectTree');

            });


            Route::group(['prefix' => 'point'], function () {
                Route::get('/', 'PointsController@index');
                Route::post('/', 'PointsController@store');
                Route::get('/info/{id}', 'PointsController@show');
                Route::put('/{id}', 'PointsController@update');
                Route::delete('/{id}', 'PointsController@destroy');
                Route::get('/select-options', 'PointsController@SelectOptions');

                Route::get('/areas', 'PointsController@project');
                Route::get('/select-options-trees', 'PointsController@selectOptionTrees');
            });
        });
    });

});

//附件下载
//Route::get('/view/attach-download/{id}', 'Course\AttachController@download');

Route::get('/', function () {
    return app()->version();
});

//开发环境接口
Route::group(['prefix' => 'develop'], function () {
    //响应状态
//    Route::get('/http-status', 'DevelopController@httpStatus');
    Route::post('/t', 'ExampleController@test');
    Route::get('/init', 'ExampleController@init');
});
